Changelog
=========

1.2.0 (2018-12-17)
==================

* Added support for Django 2.0 and 2.1
* Removed support for Django < 1.11
* Adapted testing infrastructure (tox/travis) to incorporate django CMS 3.6


1.1.0 (2017-09-02)
==================

* Dropped Django<1.8
* Dropped Python<2.7
* Added Django 1.10 and 1.11
* Fixed Category deletion


1.0.4 (2017-03-02)
==================

* Added translations from Transifex


1.0.3 (2016-05-17)
==================

* Escape category names in custom model fields
* Minor adjustments to admin presentation
* Update test environments, config


1.0.2 (2016-02-12)
==================

* Use aldryn-translation-tools for slug generation
* Improve test suite with Django 1.9 support


1.0.1 (2015-11-12)
==================

* CMS 3.2 Wizard


1.0.0 (2015-08-05)
==================

* Improved test coverage to 100%
* Updates test configuration to test for Django 1.8 compatibility
* Category* model fields use 'Category' as the default `to` field.
* Adds documentation


0.2.0 (2015-07-09)
==================

* Added Support for One-to-One and FK relationships
